@@ -4,24 +4,23 @@ from pyspark.sql import DataFrame, Column
 
 from spark_auto_mapper.data_types.array_base import AutoMapperArrayLikeBase
 from spark_auto_mapper.data_types.data_type_base import AutoMapperDataTypeBase
-from spark_auto_mapper.type_definitions.wrapper_types import AutoMapperAnyDataType, AutoMapperColumnOrColumnLikeType
-
-_TAutoMapperDataType = TypeVar(
-    "_TAutoMapperDataType", bound=AutoMapperAnyDataType
+from spark_auto_mapper.type_definitions.wrapper_types import (
+    AutoMapperAnyDataType,
+    AutoMapperColumnOrColumnLikeType,
 )
 
+_TAutoMapperDataType = TypeVar("_TAutoMapperDataType", bound=AutoMapperAnyDataType)
 
-class AutoMapperFirstDataType(
-    AutoMapperArrayLikeBase, Generic[_TAutoMapperDataType]
-):
+
+class AutoMapperFirstDataType(AutoMapperArrayLikeBase, Generic[_TAutoMapperDataType]):
     def __init__(
-        self, column: Union[AutoMapperDataTypeBase,
-                            AutoMapperColumnOrColumnLikeType]
+        self, column: Union[AutoMapperDataTypeBase, AutoMapperColumnOrColumnLikeType]
     ) -> None:
         super().__init__()
 
-        self.column: Union[AutoMapperDataTypeBase,
-                           AutoMapperColumnOrColumnLikeType] = column
+        self.column: Union[
+            AutoMapperDataTypeBase, AutoMapperColumnOrColumnLikeType
+        ] = column
 
     def get_column_spec(
         self, source_df: Optional[DataFrame], current_column: Optional[Column]
